==> qpcR_1.1-7.tar.gz: qpcR/R/expfit.R <==
expfit <- function(
object,
method = c("outlier", "midpoint", "ERBCP"),
### outlier
pval = 0.05,
n.outl = 3,
### midpoint
n.ground = 10,
### ERBCP
corfact = 1,
### all methods
fix = c("top", "bottom", "middle"),
nfit = 5,
plot = TRUE,
...
)
{
      method <- match.arg(method)
      fix <- match.arg(fix)
      cyc <- object$data[, 1]
      fluo <- object$data[, 2]
                  
      ### outlier method
      if (method == "outlier") {
            result <- outlier(object, pval = pval, nsig = n.outl)
            OUTLIER <- result$outl
            CYCS <- OUTLIER:(OUTLIER + nfit - 1)
      }
      
      ### midpoint method
      if (method == "midpoint") {
            result <- midpoint(object, first.cyc = n.ground)
            midpoint <- result$mp
            MIDPOINT <- round(midpoint)
            if (fix == "top") CYCS <- (MIDPOINT - nfit + 1):MIDPOINT
            if (fix == "bottom") CYCS <- MIDPOINT:(MIDPOINT + nfit - 1)
            if (fix == "middle") CYCS <- (MIDPOINT - (round(nfit/2 - 1))):(MIDPOINT + (round(nfit/2)))
      }
      
      ### ERBCP (Exponential Region By Crossing Points) method
      if (method == "ERBCP") {
            result <- efficiency(object, plot = FALSE)
            cpD1 <- result$cpD1
            cpD2 <- result$cpD2
            expreg <- cpD2 - corfact * (cpD1 - cpD2)
            EXPREG <- round(expreg)
            if (fix == "top") CYCS <- (EXPREG - nfit + 1):EXPREG
            if (fix == "bottom") CYCS <- EXPREG:(EXPREG + nfit - 1)
            if (fix == "middle") CYCS <- (EXPREG - (round(nfit/2 - 1))):(EXPREG + (round(nfit/2)))
      }
      
      ### calculate exponential model
      expMod <- update(object, data = object$data[CYCS, 1:2], fct = qpcR:::expGrowth())
      EFF <- exp(as.numeric(coef(expMod)[2]))
      
      POINT <- switch(method, outlier = OUTLIER, midpoint = MIDPOINT, ERBCP = EXPREG)	

      if (plot) {
            pcrplot(object, xlab = "Cycles", ylab = "raw fluorescence", ...)
            pcrplot(expMod, add = TRUE, col = 3, lwd = 2)
            points(POINT, pcrpred(object, POINT, "y"), col = 2, pch = 16)
      }

      return(list(point = POINT, cycles = CYCS, eff = as.numeric(exp(coef(expMod)[2])),
            eff.cycles = object$data[CYCS, 2]/object$data[CYCS - 1, 2],
            AIC = AIC(expMod), resVar = resVar(expMod), RMSE = RMSE(expMod),
            init = as.numeric(coef(expMod)[1]), mod = expMod))
}

==> qpcR_1.1-8.tar.gz: qpcR/R/expfit.R <==
expfit <- function(
object,
method = c("outlier", "midpoint", "ERBCP"),
### outlier
pval = 0.05,
n.outl = 3,
### midpoint
n.ground = 10,
### ERBCP
corfact = 1,
### all methods
fix = c("top", "bottom", "middle"),
nfit = 5,
plot = TRUE,
...
)
{
      method <- match.arg(method)
      fix <- match.arg(fix)
      cyc <- object$data[, 1]
      fluo <- object$data[, 2]
                  
      ### outlier method
      if (method == "outlier") {
            result <- qpcR:::outlier(object, pval = pval, nsig = n.outl)
            OUTLIER <- result$outl
            CYCS <- OUTLIER:(OUTLIER + nfit - 1)
      }
      
      ### midpoint method
      if (method == "midpoint") {
            result <- qpcR:::midpoint(object, first.cyc = n.ground)
            midpoint <- result$mp
            MIDPOINT <- round(midpoint)
            if (fix == "top") CYCS <- (MIDPOINT - nfit + 1):MIDPOINT
            if (fix == "bottom") CYCS <- MIDPOINT:(MIDPOINT + nfit - 1)
            if (fix == "middle") CYCS <- (MIDPOINT - (round(nfit/2 - 1))):(MIDPOINT + (round(nfit/2)))
      }
      
      ### ERBCP (Exponential Region By Crossing Points) method
      if (method == "ERBCP") {
            result <- efficiency(object, plot = FALSE)
            cpD1 <- result$cpD1
            cpD2 <- result$cpD2
            expreg <- cpD2 - corfact * (cpD1 - cpD2)
            EXPREG <- round(expreg)
            if (fix == "top") CYCS <- (EXPREG - nfit + 1):EXPREG
            if (fix == "bottom") CYCS <- EXPREG:(EXPREG + nfit - 1)
            if (fix == "middle") CYCS <- (EXPREG - (round(nfit/2 - 1))):(EXPREG + (round(nfit/2)))
      }
      
      ### calculate exponential model
      expMod <- update(object, data = object$data[CYCS, 1:2], fct = qpcR:::expGrowth())
      EFF <- exp(as.numeric(coef(expMod)[2]))
      
      POINT <- switch(method, outlier = OUTLIER, midpoint = MIDPOINT, ERBCP = EXPREG)	

      if (plot) {
            pcrplot(object, xlab = "Cycles", ylab = "raw fluorescence", ...)
            pcrplot(expMod, add = TRUE, col = 3, lwd = 2)
            points(POINT, pcrpred(object, POINT, "y"), col = 2, pch = 16)
      }

      return(list(point = POINT, cycles = CYCS, eff = as.numeric(exp(coef(expMod)[2])),
            eff.cycles = object$data[CYCS, 2]/object$data[CYCS - 1, 2],
            AIC = AIC(expMod), resVar = resVar(expMod), RMSE = RMSE(expMod),
            init = as.numeric(coef(expMod)[1]), mod = expMod))
}
